@@ -57,6 +57,7 @@ LeftListView::LeftListView(QWidget *parent)
     , m_pMountLabel(nullptr), m_pMountListWidget(nullptr), m_pMountWidget(nullptr)
     , m_ItemCurrentName(COMMON_STR_RECENT_IMPORTED)
     , m_ItemCurrentType(COMMON_STR_RECENT_IMPORTED)
+    , m_currentUID(-1)
     , m_pMenu(nullptr)
 {
     //右侧菜单栏支持滑动
@@ -505,9 +506,11 @@ void LeftListView::onPhotoLibListViewPressed(const QModelIndex &index)
         if (COMMON_STR_RECENT_IMPORTED == item->m_albumNameStr) {
             m_ItemCurrentName = COMMON_STR_RECENT_IMPORTED;
             m_ItemCurrentType = COMMON_STR_RECENT_IMPORTED;
+            m_currentUID = -1;
         } else if (COMMON_STR_TRASH == item->m_albumNameStr) {
             m_ItemCurrentName = COMMON_STR_TRASH;
             m_ItemCurrentType = COMMON_STR_TRASH;
+            m_currentUID = -1;
         } else {
             m_ItemCurrentName = COMMON_STR_FAVORITES;
             m_ItemCurrentType = COMMON_STR_FAVORITES;
@@ -597,9 +600,11 @@ void LeftListView::onPhotoLibListViewCurrentItemChanged()
         if (COMMON_STR_RECENT_IMPORTED == item->m_albumNameStr) {
             m_ItemCurrentName = COMMON_STR_RECENT_IMPORTED;
             m_ItemCurrentType = COMMON_STR_RECENT_IMPORTED;
+            m_currentUID = -1;
         } else if (COMMON_STR_TRASH == item->m_albumNameStr) {
             m_ItemCurrentName = COMMON_STR_TRASH;
             m_ItemCurrentType = COMMON_STR_TRASH;
+            m_currentUID = -1;
         } else {
             m_ItemCurrentName = COMMON_STR_FAVORITES;
             m_ItemCurrentType = COMMON_STR_FAVORITES;
@@ -773,10 +778,10 @@ void LeftListView::updateAlbumItemsColor()
 
 void LeftListView::resizeEvent(QResizeEvent *e)
 {
-    DWidget::resizeEvent(e);
     // 设备左边栏
     int deviceHeight = m_pMountListWidget->count() * LEFT_VIEW_LISTITEM_HEIGHT_40;
     m_pMountListWidget->setFixedHeight(deviceHeight);
+    DScrollArea::resizeEvent(e);
 }
 
 void LeftListView::mousePressEvent(QMouseEvent *e)
