@@ -25,6 +25,7 @@
 #include "mainwindow.h"
 #include "imageengineapi.h"
 
+std::atomic_bool SignalManager::inAutoImport;
 SignalManager *SignalManager::m_signalManager = nullptr;
 SignalManager *SignalManager::instance()
 {
@@ -32,6 +33,8 @@ SignalManager *SignalManager::instance()
         m_signalManager = new SignalManager;
     }
 
+    inAutoImport = false;
+
     return m_signalManager;
 }
 
