@@ -50,6 +50,8 @@ public:
 
     void showInfoDlg(const QString &path, ItemType type, bool isTrash);
 
+    static std::atomic_bool inAutoImport;
+
 signals:
     void hideImageView();
     void showSlidePanel(int index);
@@ -125,6 +127,9 @@ signals:
     //自动导入路径被删除
     void sigMonitorDestroyed(int UID);
 
+    //需要重新加载缩略图
+    void needReflushThumbnail(const QStringList &paths);
+
 private:
     explicit SignalManager(QObject *parent = nullptr);
 
