@@ -32,17 +32,10 @@
 #include <QSqlError>
 #include <QSqlQuery>
 #include <QStandardPaths>
+#include <QtConcurrent/QtConcurrent>
 
 #include "imageengineapi.h"
 
-namespace {
-const QString DATABASE_PATH = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation)
-                              + QDir::separator() + "deepin" + QDir::separator() + "deepin-album" + QDir::separator();
-const QString DATABASE_NAME = "deepinalbum.db";
-const QString EMPTY_HASH_STR = utils::base::hashByString(QString(" "));
-
-}  // namespace
-
 DBManager *DBManager::m_dbManager = nullptr;
 std::once_flag DBManager::instanceFlag;
 QReadWriteLock DBManager::m_fileMutex;
@@ -59,6 +52,11 @@ DBManager *DBManager::instance()
 DBManager::DBManager(QObject *parent)
     : QObject(parent)
 {
+    //指定路径
+    DATABASE_PATH = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QDir::separator();
+    qDebug() << "----current DataBase path--" << DATABASE_PATH;
+    DATABASE_NAME = "deepinalbum.db";
+    EMPTY_HASH_STR = utils::base::hashByString(QString(" "));
     checkDatabase();
 }
 
@@ -97,9 +95,9 @@ const DBImgInfoList DBManager::getAllInfos(int loadCount)const
         while (m_query->next()) {
             DBImgInfo info;
             info.filePath = m_query->value(0).toString();
-            info.time = stringToDateTime(m_query->value(3).toString());
-            info.changeTime = QDateTime::fromString(m_query->value(4).toString(), DATETIME_FORMAT_DATABASE);
-            info.importTime = QDateTime::fromString(m_query->value(5).toString(), DATETIME_FORMAT_DATABASE);
+            info.time = m_query->value(3).toDateTime();
+            info.changeTime = m_query->value(4).toDateTime();
+            info.importTime = m_query->value(5).toDateTime();
             info.itemType = static_cast<ItemType>(m_query->value(6).toInt());
             infos << info;
         }
@@ -107,60 +105,83 @@ const DBImgInfoList DBManager::getAllInfos(int loadCount)const
     return infos;
 }
 
-const QStringList DBManager::getAllTimelines() const
+const QList<QDateTime> DBManager::getAllTimelines() const
 {
     QMutexLocker mutex(&m_dbMutex);
-    QStringList times;
+    QList<QDateTime> times;
     m_query->setForwardOnly(true);
     if (!m_query->exec("SELECT DISTINCT Time FROM ImageTable3 ORDER BY Time DESC")) {
         return times;
     } else {
         while (m_query->next()) {
-            times << m_query->value(0).toString();
+            times << m_query->value(0).toDateTime();
         }
     }
     return times;
 }
 
-const DBImgInfoList DBManager::getInfosByTimeline(const QString &timeline) const
-{
-    const DBImgInfoList list = getImgInfos("Time", timeline);
-    if (list.count() < 1) {
-        return DBImgInfoList();
-    } else {
-        return list;
-    }
-}
-
-const QStringList DBManager::getImportTimelines() const
+const DBImgInfoList DBManager::getInfosByTimeline(const QDateTime &timeline) const
 {
     QMutexLocker mutex(&m_dbMutex);
-    QStringList importtimes;
-
+    DBImgInfoList infos;
     m_query->setForwardOnly(true);
-    if (!m_query->exec("SELECT DISTINCT ImportTime FROM ImageTable3 ORDER BY ImportTime DESC")) {
-        return importtimes;
+
+    bool b = m_query->prepare(QString("SELECT FilePath, FileType FROM ImageTable3 "
+                                      "WHERE Time = :Date ORDER BY Time DESC"));
+    m_query->bindValue(":Date", timeline);
+    if (!b || !m_query->exec()) {
     } else {
         while (m_query->next()) {
-            importtimes << m_query->value(0).toString();
+            DBImgInfo info;
+            info.filePath = m_query->value(0).toString();
+            info.itemType = static_cast<ItemType>(m_query->value(1).toInt());
+            infos << info;
+        }
+    }
+
+    return infos;
+}
+
+const QList<QDateTime> DBManager::getImportTimelines() const
+{
+    QMutexLocker mutex(&m_dbMutex);
+    QList<QDateTime> importtimes;
+
+    m_query->setForwardOnly(true);
+    if (!m_query->exec("SELECT DISTINCT STRFTIME(\"%Y-%m-%d %H:%M\", ImportTime) FROM ImageTable3 ORDER BY ImportTime DESC")) {
+    } else {
+        while (m_query->next()) {
+            importtimes << m_query->value(0).toDateTime();
         }
     }
     return importtimes;
 }
 
-const DBImgInfoList DBManager::getInfosByImportTimeline(const QString &timeline) const
+const DBImgInfoList DBManager::getInfosByImportTimeline(const QDateTime &timeline) const
 {
-    const DBImgInfoList list = getImgInfos("ImportTime", timeline);
-    if (list.count() < 1) {
-        return DBImgInfoList();
+    QMutexLocker mutex(&m_dbMutex);
+    DBImgInfoList infos;
+    m_query->setForwardOnly(true);
+
+    bool b = m_query->prepare(QString("SELECT FilePath, FileType FROM ImageTable3 "
+                                      "WHERE STRFTIME(\"%Y-%m-%d %H:%M\", ImportTime) = STRFTIME(\"%Y-%m-%d %H:%M\", :Date) ORDER BY Time DESC"));
+    m_query->bindValue(":Date", timeline);
+    if (!b || !m_query->exec()) {
     } else {
-        return list;
+        while (m_query->next()) {
+            DBImgInfo info;
+            info.filePath = m_query->value(0).toString();
+            info.itemType = static_cast<ItemType>(m_query->value(1).toInt());
+            infos << info;
+        }
     }
+
+    return infos;
 }
 
 const DBImgInfo DBManager::getInfoByPath(const QString &path) const
 {
-    DBImgInfoList list = getImgInfos("FilePath", path);
+    DBImgInfoList list = getImgInfos("FilePath", path, true);
     if (list.count() != 1) {
         return DBImgInfo();
     } else {
@@ -198,9 +219,9 @@ void DBManager::insertImgInfos(const DBImgInfoList &infos)
         m_query->addBindValue(utils::base::hashByString(info.filePath));
         m_query->addBindValue(info.filePath);
         m_query->addBindValue(info.getFileNameFromFilePath());
-        m_query->addBindValue(info.time.toString("yyyy.MM.dd"));
-        m_query->addBindValue(info.changeTime.toString(DATETIME_FORMAT_DATABASE));
-        m_query->addBindValue(info.importTime.toString(DATETIME_FORMAT_DATABASE));
+        m_query->addBindValue(info.time);
+        m_query->addBindValue(info.changeTime);
+        m_query->addBindValue(info.importTime);
         m_query->addBindValue(info.itemType);
         if (!m_query->exec()) {
             ;
@@ -290,29 +311,23 @@ void DBManager::removeImgInfosNoSignal(const QStringList &paths)
     if (!m_query->exec("BEGIN IMMEDIATE TRANSACTION")) {
 //        qDebug() << "begin transaction failed.";
     }
-    QString qs("DELETE FROM AlbumTable3 WHERE PathHash=:hash");
-    if (!m_query->prepare(qs)) {
-    }
+    QString qs("DELETE FROM AlbumTable3 WHERE PathHash=\"%1\"");
     for (auto &eachHash : pathHashs) {
-        m_query->bindValue(":hash", eachHash);
-        if (!m_query->exec()) {
+        if (!m_query->exec(qs.arg(eachHash))) {
             ;
         }
     }
 
     if (!m_query->exec("COMMIT")) {
-//        qDebug() << "COMMIT failed.";
+        //        qDebug() << "COMMIT failed.";
     }
 
     // Remove from image table
     if (!m_query->exec("BEGIN IMMEDIATE TRANSACTION")) {
     }
-    qs = "DELETE FROM ImageTable3 WHERE PathHash=:hash";
-    if (!m_query->prepare(qs)) {
-    }
+    qs = "DELETE FROM ImageTable3 WHERE PathHash=\"%1\"";
     for (auto &eachHash : pathHashs) {
-        m_query->bindValue(":hash", eachHash);
-        if (!m_query->exec()) {
+        if (!m_query->exec(qs.arg(eachHash))) {
         }
     }
 
@@ -460,30 +475,45 @@ const QStringList DBManager::getPathsByAlbum(int UID) const
     return list;
 }
 
-const DBImgInfoList DBManager::getInfosByAlbum(int UID) const
+const DBImgInfoList DBManager::getInfosByAlbum(int UID, bool needTimeData) const
 {
     QMutexLocker mutex(&m_dbMutex);
     DBImgInfoList infos;
     m_query->setForwardOnly(true);
-    bool b = m_query->prepare("SELECT DISTINCT i.FilePath, i.FileName, i.FileType, i.Time, i.ChangeTime, i.ImportTime "
-                              "FROM ImageTable3 AS i, AlbumTable3 AS a "
-                              "WHERE i.PathHash=a.PathHash "
-                              "AND a.UID=:UID ");
-    m_query->bindValue(":UID", UID);
-    if (!b || ! m_query->exec()) {
-        //    qWarning() << "Get ImgInfo by album failed: " << query.lastError();
+
+    if (needTimeData) {
+        bool b = m_query->prepare(QString("SELECT DISTINCT i.FilePath, i.FileType, i.Time, i.ChangeTime, i.ImportTime "
+                                          "FROM ImageTable3 AS i, AlbumTable3 AS a "
+                                          "WHERE i.PathHash=a.PathHash "
+                                          "AND a.UID=:UID ORDER BY Time DESC").arg(UID));
+        if (!b || ! m_query->exec()) {
+        } else {
+            while (m_query->next()) {
+                DBImgInfo info;
+                info.filePath = m_query->value(0).toString();
+                info.itemType = static_cast<ItemType>(m_query->value(1).toInt());
+                info.time = m_query->value(2).toDateTime();
+                info.changeTime = m_query->value(3).toDateTime();
+                info.importTime = m_query->value(4).toDateTime();
+                infos << info;
+            }
+        }
     } else {
-        using namespace utils::base;
-        while (m_query->next()) {
-            DBImgInfo info;
-            info.filePath = m_query->value(0).toString();
-            info.itemType = static_cast<ItemType>(m_query->value(2).toInt());
-            info.time = stringToDateTime(m_query->value(3).toString());
-            info.changeTime = QDateTime::fromString(m_query->value(4).toString(), DATETIME_FORMAT_DATABASE);
-            info.importTime = QDateTime::fromString(m_query->value(5).toString(), DATETIME_FORMAT_DATABASE);
-            infos << info;
+        bool b = m_query->prepare(QString("SELECT DISTINCT i.FilePath, i.FileType "
+                                          "FROM ImageTable3 AS i, AlbumTable3 AS a "
+                                          "WHERE i.PathHash=a.PathHash "
+                                          "AND a.UID=%1 ORDER BY Time DESC").arg(UID));
+        if (!b || ! m_query->exec()) {
+        } else {
+            while (m_query->next()) {
+                DBImgInfo info;
+                info.filePath = m_query->value(0).toString();
+                info.itemType = static_cast<ItemType>(m_query->value(1).toInt());
+                infos << info;
+            }
         }
     }
+
     return infos;
 }
 
@@ -549,19 +579,17 @@ bool DBManager::isAllImgExistInAlbum(int UID, const QStringList &paths, AlbumDBT
     }
 }
 
-bool DBManager::isImgExistInAlbum(int UID, const QString &path, AlbumDBType atype) const
+bool DBManager::isImgExistInAlbum(int UID, const QString &path) const
 {
     QMutexLocker mutex(&m_dbMutex);
     m_query->setForwardOnly(true);
     bool b = m_query->prepare("SELECT COUNT(*) FROM AlbumTable3 WHERE PathHash = :hash "
-                              "AND UID = :UID "
-                              "AND AlbumDBType =:atype ");
+                              "AND UID = :UID ");
     if (!b) {
         return false;
     }
     m_query->bindValue(":hash", utils::base::hashByString(path));
     m_query->bindValue(":UID", UID);
-    m_query->bindValue(":atype", atype);
     if (m_query->exec()) {
         m_query->first();
         return (m_query->value(0).toInt() == 1);
@@ -674,8 +702,10 @@ bool DBManager::insertIntoAlbum(int UID, const QStringList &paths, AlbumDBType a
     if (!m_query->prepare(qs)) {
     }
     for (auto &eachPath : paths) {
-        m_query->addBindValue(utils::base::hashByString(eachPath));
-        if (!m_query->exec()) {
+        if (QFile::exists(eachPath)) { //需要路径存在才能执行添加到相册
+            m_query->addBindValue(utils::base::hashByString(eachPath));
+            if (!m_query->exec()) {
+            }
         }
     }
 
@@ -740,7 +770,7 @@ void DBManager::removeFromAlbum(int UID, const QStringList &paths, AlbumDBType a
 void DBManager::renameAlbum(int UID, const QString &newAlbum, AlbumDBType atype)
 {
     QMutexLocker mutex(&m_dbMutex);
-    if (!m_query->exec(QString("UPDATE AlbumTable3 SET AlbumName=%1 WHERE UID=%2 AND AlbumDBType=%3").arg(newAlbum).arg(UID).arg(atype))) {
+    if (!m_query->exec(QString("UPDATE AlbumTable3 SET AlbumName=\"%1\" WHERE UID=%2 AND AlbumDBType=%3").arg(newAlbum).arg(UID).arg(atype))) {
     }
 }
 
@@ -761,9 +791,9 @@ const DBImgInfoList DBManager::getInfosByNameTimeline(const QString &value) cons
         while (m_query->next()) {
             DBImgInfo info;
             info.filePath = m_query->value(0).toString();
-            info.time = stringToDateTime(m_query->value(3).toString());
-            info.changeTime = QDateTime::fromString(m_query->value(4).toString(), DATETIME_FORMAT_DATABASE);
-            info.importTime = QDateTime::fromString(m_query->value(5).toString(), DATETIME_FORMAT_DATABASE);
+            info.time = m_query->value(3).toDateTime();
+            info.changeTime = m_query->value(4).toDateTime();
+            info.importTime = m_query->value(5).toDateTime();
             info.itemType = static_cast<ItemType>(m_query->value(6).toInt());
             infos << info;
         }
@@ -799,9 +829,9 @@ const DBImgInfoList DBManager::getTrashInfosForKeyword(const QString &keywords)
         while (m_query->next()) {
             DBImgInfo info;
             info.filePath = m_query->value(0).toString();
-            info.time = stringToDateTime(m_query->value(3).toString());
-            info.changeTime = QDateTime::fromString(m_query->value(4).toString(), DATETIME_FORMAT_DATABASE);
-            info.importTime = QDateTime::fromString(m_query->value(5).toString(), DATETIME_FORMAT_DATABASE);
+            info.time = m_query->value(3).toDateTime();
+            info.changeTime = m_query->value(4).toDateTime();
+            info.importTime = m_query->value(5).toDateTime();
             info.itemType = ItemType(m_query->value(6).toInt());
             infos << info;
         }
@@ -830,9 +860,9 @@ const DBImgInfoList DBManager::getInfosForKeyword(int UID, const QString &keywor
         while (m_query->next()) {
             DBImgInfo info;
             info.filePath = m_query->value(0).toString();
-            info.time = stringToDateTime(m_query->value(3).toString());
-            info.changeTime = QDateTime::fromString(m_query->value(4).toString(), DATETIME_FORMAT_DATABASE);
-            info.importTime = QDateTime::fromString(m_query->value(5).toString(), DATETIME_FORMAT_DATABASE);
+            info.time = m_query->value(3).toDateTime();
+            info.changeTime = m_query->value(4).toDateTime();
+            info.importTime = m_query->value(5).toDateTime();
             infos << info;
         }
     }
@@ -863,27 +893,38 @@ const QMultiMap<QString, QString> DBManager::getAllPathAlbumNames() const
     return infos;
 }
 
-const DBImgInfoList DBManager::getImgInfos(const QString &key, const QString &value) const
+const DBImgInfoList DBManager::getImgInfos(const QString &key, const QString &value, bool needTimeData) const
 {
     QMutexLocker mutex(&m_dbMutex);
     DBImgInfoList infos;
     m_query->setForwardOnly(true);
-    bool b = m_query->prepare(QString("SELECT FilePath, FileName, Dir, Time, ChangeTime, ImportTime, FileType FROM ImageTable3 "
-                                      "WHERE %1= :value ORDER BY Time DESC").arg(key));
 
-    m_query->bindValue(":value", value);
-
-    if (!b || !m_query->exec()) {
-    } else {
-        using namespace utils::base;
-        while (m_query->next()) {
-            DBImgInfo info;
-            info.filePath = m_query->value(0).toString();
-            info.time = stringToDateTime(m_query->value(3).toString());
-            info.changeTime = QDateTime::fromString(m_query->value(4).toString(), DATETIME_FORMAT_DATABASE);
-            info.importTime = QDateTime::fromString(m_query->value(5).toString(), DATETIME_FORMAT_DATABASE);
-            info.itemType = static_cast<ItemType>(m_query->value(6).toInt());
-            infos << info;
+    if (needTimeData) {
+        bool b = m_query->prepare(QString("SELECT FilePath, Time, ChangeTime, ImportTime, FileType FROM ImageTable3 "
+                                          "WHERE %1= \"%2\" ORDER BY Time DESC").arg(key).arg(value));
+        if (!b || !m_query->exec()) {
+        } else {
+            while (m_query->next()) {
+                DBImgInfo info;
+                info.filePath = m_query->value(0).toString();
+                info.time = m_query->value(1).toDateTime();
+                info.changeTime = m_query->value(2).toDateTime();
+                info.importTime = m_query->value(3).toDateTime();
+                info.itemType = static_cast<ItemType>(m_query->value(4).toInt());
+                infos << info;
+            }
+        }
+    } else { //取消读取时间数据以加速
+        bool b = m_query->prepare(QString("SELECT FilePath, FileType FROM ImageTable3 "
+                                          "WHERE %1= \"%2\" ORDER BY Time DESC").arg(key).arg(value));
+        if (!b || !m_query->exec()) {
+        } else {
+            while (m_query->next()) {
+                DBImgInfo info;
+                info.filePath = m_query->value(0).toString();
+                info.itemType = static_cast<ItemType>(m_query->value(1).toInt());
+                infos << info;
+            }
         }
     }
     return infos;
@@ -896,7 +937,13 @@ bool DBManager::checkCustomAutoImportPathIsNotified(const QString &path)
     auto pathsList = std::get<0>(defaultPath);
     for (auto &eachPath : pathsList) {
         if (path.startsWith(eachPath) || eachPath.startsWith(path)) {
-            return true;
+            if (path.size() > eachPath.size() && path.at(eachPath.size()) == '/') {
+                return true;
+            } else if (eachPath.size() > path.size() && eachPath.at(path.size()) == '/') {
+                return true;
+            } else if (eachPath.size() == path.size()) {
+                return true;
+            }
         }
     }
 
@@ -908,9 +955,15 @@ bool DBManager::checkCustomAutoImportPathIsNotified(const QString &path)
     }
 
     while (m_query->next()) {
-        auto currentPath = m_query->value(0).toString();
-        if (path.startsWith(currentPath) || currentPath.startsWith(path)) {
-            return true;
+        auto eachPath = m_query->value(0).toString();
+        if (path.startsWith(eachPath) || eachPath.startsWith(path)) {
+            if (path.size() > eachPath.size() && path.at(eachPath.size()) == '/') {
+                return true;
+            } else if (eachPath.size() > path.size() && eachPath.at(path.size()) == '/') {
+                return true;
+            } else if (eachPath.size() == path.size()) {
+                return true;
+            }
         }
     }
 
@@ -962,6 +1015,19 @@ void DBManager::removeCustomAutoImportPath(int UID)
     }
 
     //1.删除图片
+
+    //1.1查询要删除的图片的路径，后面用于通知上层UI进行改变
+    QStringList paths;
+    if (!m_query->prepare("SELECT FilePath FROM ImageTable3 WHERE PathHash=:hash")) {
+    }
+    for (auto &eachHash : hashs) {
+        m_query->bindValue(":hash", eachHash);
+        if (!m_query->exec() || !m_query->next()) {
+        }
+        paths.push_back(m_query->value(0).toString());
+    }
+
+    //1.2执行删除
     if (!m_query->prepare("DELETE FROM ImageTable3 WHERE PathHash=:hash")) {
     }
     for (auto &eachHash : hashs) {
@@ -993,6 +1059,7 @@ void DBManager::removeCustomAutoImportPath(int UID)
     //发送信号通知上层
     mutex.unlock();
     emit dApp->signalM->imagesRemoved();
+    emit dApp->signalM->imagesRemovedPar(paths);
 }
 
 std::map<int, QString> DBManager::getAllCustomAutoImportUIDAndPath()
@@ -1030,12 +1097,13 @@ void DBManager::checkDatabase()
     m_query = new QSqlQuery(db);
 
     // 创建Table的语句都是加了IF NOT EXISTS的，直接运行就可以了
+    // 注释里面的是实际我们希望的类型，而下面的SQL语句是SQLite3接受的类型
 
     // ImageTable3
-    //////////////////////////////////////////////////////////////
-    //PathHash           | FilePath | FileName   | Dir  | Time | ChangeTime | ImportTime//
-    //TEXT primari key   | TEXT     | TEXT       | TEXT | TEXT | TEXT       | TEXT      //
-    //////////////////////////////////////////////////////////////
+    /////////////////////////////////////////////////////////////////////////////////////////////////////
+    //PathHash                    | FilePath | FileName   | Dir  | Time      | ChangeTime | ImportTime //
+    //CHARACTER(32) primari key   | TEXT     | TEXT       | TEXT | TIMESTAMP | TIMESTAMP  | TIMESTAMP  //
+    /////////////////////////////////////////////////////////////////////////////////////////////////////
     bool b = m_query->exec(QString("CREATE TABLE IF NOT EXISTS ImageTable3 ( "
                                    "PathHash TEXT primary key, "
                                    "FilePath TEXT, "
@@ -1052,23 +1120,23 @@ void DBManager::checkDatabase()
 
     // AlbumTable3
     ///////////////////////////////////////////////////////////////////////////////////////
-    //AlbumId               | AlbumName         | PathHash      |AlbumDBType    |UID     //
-    //INTEGER primari key   | TEXT              | TEXT          |TEXT           |INTEGER //
+    //AlbumId               | AlbumName    | PathHash        |AlbumDBType    |UID        //
+    //INTEGER primari key   | TEXT         | CHARACTER(32)   |TEXT           |INTEGER    //
     ///////////////////////////////////////////////////////////////////////////////////////
     bool c = m_query->exec(QString("CREATE TABLE IF NOT EXISTS AlbumTable3 ( "
                                    "AlbumId INTEGER primary key, "
                                    "AlbumName TEXT, "
-                                   "PathHash TEXT,"
+                                   "PathHash TEXT, "
                                    "AlbumDBType INTEGER,"
                                    "UID INTEGER)"));
     if (!c) {
         qDebug() << "c CREATE TABLE exec failed.";
     }
     // TrashTable3
-    //////////////////////////////////////////////////////////////
-    //PathHash           | FilePath | FileName   | Dir  | Time | ChangeTime | ImportTime//
-    //TEXT primari key   | TEXT     | TEXT       | TEXT | TEXT | TEXT       | TEXT      //
-    //////////////////////////////////////////////////////////////
+    /////////////////////////////////////////////////////////////////////////////////////////////////////
+    //PathHash                    | FilePath | FileName   | Dir  | Time      | ChangeTime | ImportTime //
+    //CHARACTER(32) primari key   | TEXT     | TEXT       | TEXT | TIMESTAMP | TIMESTAMP  | TIMESTAMP  //
+    /////////////////////////////////////////////////////////////////////////////////////////////////////
     bool d = m_query->exec(QString("CREATE TABLE IF NOT EXISTS TrashTable3 ( "
                                    "PathHash TEXT primary key, "
                                    "FilePath TEXT, "
@@ -1076,7 +1144,7 @@ void DBManager::checkDatabase()
                                    "Dir TEXT, "
                                    "Time TEXT, "
                                    "ChangeTime TEXT, "
-                                   "ImportTime TEXT,"
+                                   "ImportTime TEXT, "
                                    "FileType INTEGER)"));
     if (!d) {
         qDebug() << "d CREATE TABLE exec failed.";
@@ -1102,8 +1170,7 @@ void DBManager::checkDatabase()
     if (!q && m_query->next()) {
         // 无ChangeTime字段,则增加ChangeTime字段,赋值当前时间
         QString strDate = QDateTime::currentDateTime().toString(DATETIME_FORMAT_DATABASE);
-        if (m_query->exec(QString("ALTER TABLE \"ImageTable3\" ADD COLUMN \"ChangeTime\" TEXT default \"%1\"")
-                          .arg(strDate))) {
+        if (m_query->exec(QString("ALTER TABLE \"ImageTable3\" ADD COLUMN \"ChangeTime\" TEXT"))) {
             qDebug() << "add ChangeTime success";
         }
     }
@@ -1116,8 +1183,7 @@ void DBManager::checkDatabase()
     if (!m_query->next()) {
         // 无ImportTime字段,则增加ImportTime字段
         QString strDate = QDateTime::currentDateTime().toString(DATETIME_FORMAT_DATABASE);
-        if (m_query->exec(QString("ALTER TABLE \"ImageTable3\" ADD COLUMN \"ImportTime\" TEXT default \"%1\"")
-                          .arg(strDate))) {
+        if (m_query->exec(QString("ALTER TABLE \"ImageTable3\" ADD COLUMN \"ImportTime\" TEXT"))) {
             qDebug() << "add ImportTime success";
         }
     }
@@ -1185,18 +1251,12 @@ void DBManager::checkDatabase()
             nameList.push_back(currentName);
         }
 
-        //3.插入特殊UID字段
-        insertSpUID("Favorite", Favourite, u_Favorite);
-        insertSpUID("Screen Capture", AutoImport, u_ScreenCapture);//使用album name的SQL语句注意加冒号
-        insertSpUID("Camera", AutoImport, u_Camera);
-        insertSpUID("Draw", AutoImport, u_Draw);
-
-        //4.初始化max uid
+        //3.初始化max uid
         albumMaxUID = u_CustomStart;
 
-        //5.写入数据库
+        //4.写入数据库
         for (auto &currentName : nameList) {
-            if (!m_query->exec(QString("UPDATE \"AlbumTable3\" SET UID = %1 WHERE \"AlbumName\" = \"%2\"").arg(albumMaxUID++).arg(currentName))) {
+            if (!m_query->exec(QString("UPDATE AlbumTable3 SET UID = %1 WHERE AlbumName = \"%2\"").arg(albumMaxUID++).arg(currentName))) {
                 qDebug() << "update AlbumTable3 UID failed";
             }
         }
@@ -1204,13 +1264,13 @@ void DBManager::checkDatabase()
         uidIsInited = true;
     }
 
-    if (!uidIsInited) {
-        //预先插入特殊UID
-        insertSpUID("Favorite", Favourite, u_Favorite);
-        insertSpUID("Screen Capture", AutoImport, u_ScreenCapture);//使用album name的SQL语句注意加冒号
-        insertSpUID("Camera", AutoImport, u_Camera);
-        insertSpUID("Draw", AutoImport, u_Draw);
+    //插入特殊UID
+    insertSpUID("Favorite", Favourite, u_Favorite);
+    insertSpUID("Screen Capture", AutoImport, u_ScreenCapture);//使用album name的SQL语句注意加冒号
+    insertSpUID("Camera", AutoImport, u_Camera);
+    insertSpUID("Draw", AutoImport, u_Draw);
 
+    if (!uidIsInited) {
         //搜索当前最大ID值
         if (!m_query->exec("SELECT max(UID) FROM AlbumTable3") || !m_query->next()) {
             albumMaxUID = u_CustomStart; //没找到
@@ -1231,7 +1291,6 @@ void DBManager::checkDatabase()
     }
     if (!m_query->next()) {
         //无新版TrashTable，则创建新表，导入旧表数据
-        QString defaultImportTime = QDateTime::currentDateTime().toString(DATETIME_FORMAT_DATABASE);
         if (!m_query->exec(QString("CREATE TABLE IF NOT EXISTS TrashTable3 ( "
                                    "PathHash TEXT primary key, "
                                    "FilePath TEXT, "
@@ -1239,8 +1298,8 @@ void DBManager::checkDatabase()
                                    "Dir TEXT, "
                                    "Time TEXT, "
                                    "ChangeTime TEXT, "
-                                   "ImportTime TEXT default \"%1\", "
-                                   "FileType INTEGER)").arg(defaultImportTime))) {
+                                   "ImportTime TEXT, "
+                                   "FileType INTEGER)"))) {
             qDebug() << m_query->lastError();
         }
     } else {
@@ -1272,6 +1331,16 @@ void DBManager::checkDatabase()
         }
     }
 
+    //创建索引以加速
+    if (!m_query->exec("CREATE INDEX IF NOT EXISTS album_hash_index ON AlbumTable3 (PathHash)")) {
+    }
+
+    if (!m_query->exec("CREATE INDEX IF NOT EXISTS image_hash_index ON ImageTable3 (PathHash)")) {
+    }
+
+    if (!m_query->exec("CREATE INDEX IF NOT EXISTS trash_hash_index ON TrashTable3 (PathHash)")) {
+    }
+
     //新版删除需求的数据表策略
     //1.沿用老版的TrashTable3表，不做任何改变
     //2.PathHash作为存放在deepin-album-delete下的文件名，但是为了方便用户维修电脑，把原始文件名带在后面
@@ -1284,6 +1353,17 @@ void DBManager::checkDatabase()
         deleteCacheDir.mkpath(albumGlobal::DELETE_PATH);
     }
 
+    //检查时间数据，以相册版本表为准
+    if (!m_query->exec("SELECT * FROM AlbumVersion")) {
+        //创建表
+        if (!m_query->exec("CREATE TABLE AlbumVersion (version TEXT primary key)")) {
+        }
+        if (!m_query->exec("INSERT INTO AlbumVersion (version) VALUES (\"5.9\")")) {
+        }
+        checkTimeColumn("ImageTable3");
+        checkTimeColumn("TrashTable3");
+    }
+
     //每次启动后释放一次文件空间，防止占用过多无效空间
     if (!m_query->exec("VACUUM")) {
     }
@@ -1292,16 +1372,52 @@ void DBManager::checkDatabase()
     QFileInfoList deleteInfos;
     utils::image::getAllFileInDir(deleteCacheDir, deleteInfos);
     if (!deleteInfos.isEmpty()) {
-        auto fullTrashInfos = getAllTrashInfos();
+        auto fullTrashInfos = getAllTrashInfos(false);
         QStringList trashPaths;
         std::transform(fullTrashInfos.begin(), fullTrashInfos.end(), std::back_inserter(trashPaths), [](const DBImgInfo & info) {
             return utils::base::getDeleteFullPath(info.pathHash, info.getFileNameFromFilePath());
         });
-        for (const auto &eachDeleteInfo : deleteInfos) {
-            auto currentPath = eachDeleteInfo.absoluteFilePath();
+
+        auto watcher = QtConcurrent::map(deleteInfos, [trashPaths](const QFileInfo & info) {
+            auto currentPath = info.absoluteFilePath();
             if (!trashPaths.contains(currentPath)) {
                 QFile::remove(currentPath);
             }
+        });
+        watcher.waitForFinished();
+    }
+}
+
+void DBManager::checkTimeColumn(const QString &tableName)
+{
+    //检查并切换所有时间数据
+    if (m_query->exec(QString("SELECT Time, ChangeTime, ImportTime, PathHash FROM %1").arg(tableName))) {
+        std::vector<std::tuple<QString, QDateTime, QDateTime, QDateTime>> needUpdate;
+        while (m_query->next()) {
+            auto time = utils::base::analyzeDateTime(m_query->value(0));
+            auto changeTime = utils::base::analyzeDateTime(m_query->value(1));
+            auto importTime = utils::base::analyzeDateTime(m_query->value(2));
+            if (time.second || changeTime.second || importTime.second) {
+                needUpdate.push_back(std::make_tuple(m_query->value(3).toString(), time.first, changeTime.first, importTime.first));
+            }
+        }
+        if (!needUpdate.empty()) {
+            if (!m_query->exec("BEGIN IMMEDIATE TRANSACTION")) {
+            }
+
+            for (const auto &eachData : needUpdate) {
+                if (!m_query->prepare("UPDATE ImageTable3 SET Time = :t, ChangeTime = :ct, ImportTime = :it WHERE PathHash = :ph")) {
+                }
+                m_query->bindValue(":t", std::get<1>(eachData));
+                m_query->bindValue(":ct", std::get<2>(eachData));
+                m_query->bindValue(":it", std::get<3>(eachData));
+                m_query->bindValue(":ph", std::get<0>(eachData));
+                if (m_query->exec()) {
+                }
+            }
+
+            if (m_query->exec("COMMIT")) {
+            }
         }
     }
 }
@@ -1311,9 +1427,7 @@ void DBManager::insertSpUID(const QString &albumName, AlbumDBType astype, SpUID
     //0.路径不存在，BUG#111917，只检查默认路径，不要把收藏也搞进来了，否则会导致后续收藏失败
     if (UID != u_Favorite && !defaultNotifyPathExists(UID)) {
         //路径不存在则删除已有的相册
-        if (!m_query->exec(QString("DELETE FROM AlbumTable3 WHERE UID=%1").arg(UID))) {
-        }
-
+        removeCustomAutoImportPath(UID);
         return;
     }
 
@@ -1330,19 +1444,66 @@ void DBManager::insertSpUID(const QString &albumName, AlbumDBType astype, SpUID
 
     //2.1.如果是收藏的话，需要对历史收藏的图片进行迁移
     if (UID == u_Favorite) {
-        if (!m_query->exec(QString("UPDATE \"AlbumTable3\" SET UID = %1 WHERE \"AlbumDBType\" = \"%2\"").arg(UID).arg(Favourite))) {
+        if (!m_query->exec(QString("UPDATE AlbumTable3 SET UID = %1 WHERE AlbumDBType = %2").arg(UID).arg(Favourite))) {
             qDebug() << "update Favorite failed";
         }
     }
 }
 
-const DBImgInfoList DBManager::getAllTrashInfos() const
+const DBImgInfoList DBManager::getAllTrashInfos(bool needTimeData) const
 {
     QMutexLocker mutex(&m_dbMutex);
     DBImgInfoList infos;
     m_query->setForwardOnly(true);
-    bool b = m_query->prepare("SELECT FilePath, Time, ChangeTime, ImportTime, FileType, PathHash "
-                              "FROM TrashTable3 ORDER BY ImportTime DESC");
+
+    if (needTimeData) {
+        bool b = m_query->prepare("SELECT FilePath, Time, ChangeTime, ImportTime, FileType, PathHash "
+                                  "FROM TrashTable3 ORDER BY ImportTime DESC");
+        if (!b || ! m_query->exec()) {
+            return infos;
+        } else {
+            while (m_query->next()) {
+                DBImgInfo info;
+                info.filePath = m_query->value(0).toString();
+                if (info.filePath.isEmpty()) //如果路径为空
+                    continue;
+                info.time = m_query->value(1).toDateTime();
+                info.changeTime = m_query->value(2).toDateTime();
+                info.importTime = m_query->value(3).toDateTime();
+                info.itemType = ItemType(m_query->value(4).toInt());
+                info.pathHash = m_query->value(5).toString();
+                infos << info;
+            }
+        }
+    } else {
+        bool b = m_query->prepare("SELECT FilePath, FileType, PathHash "
+                                  "FROM TrashTable3 ORDER BY ImportTime DESC");
+        if (!b || ! m_query->exec()) {
+            return infos;
+        } else {
+            using namespace utils::base;
+            while (m_query->next()) {
+                DBImgInfo info;
+                info.filePath = m_query->value(0).toString();
+                if (info.filePath.isEmpty()) //如果路径为空
+                    continue;
+                info.itemType = ItemType(m_query->value(1).toInt());
+                info.pathHash = m_query->value(2).toString();
+                infos << info;
+            }
+        }
+    }
+    return infos;
+}
+
+const DBImgInfoList DBManager::getAllTrashInfos_getRemainDays() const
+{
+    QMutexLocker mutex(&m_dbMutex);
+    DBImgInfoList infos;
+    m_query->setForwardOnly(true);
+
+    //中间那坨东西就是现在距离导入的时候过了多久
+    bool b = m_query->prepare("SELECT FilePath, julianday('now') - julianday(STRFTIME(\"%Y-%m-%d\", ImportTime)), FileType, PathHash FROM TrashTable3 ORDER BY ImportTime DESC");
     if (!b || ! m_query->exec()) {
         return infos;
     } else {
@@ -1352,11 +1513,9 @@ const DBImgInfoList DBManager::getAllTrashInfos() const
             info.filePath = m_query->value(0).toString();
             if (info.filePath.isEmpty()) //如果路径为空
                 continue;
-            info.time = stringToDateTime(m_query->value(1).toString());
-            info.changeTime = QDateTime::fromString(m_query->value(2).toString(), DATETIME_FORMAT_DATABASE);
-            info.importTime = QDateTime::fromString(m_query->value(3).toString(), DATETIME_FORMAT_DATABASE);
-            info.itemType = ItemType(m_query->value(4).toInt());
-            info.pathHash = m_query->value(5).toString();
+            info.remainDays = 30 - static_cast<int>(m_query->value(1).toDouble());
+            info.itemType = ItemType(m_query->value(2).toInt());
+            info.pathHash = m_query->value(3).toString();
             infos << info;
         }
     }
@@ -1430,9 +1589,9 @@ void DBManager::insertTrashImgInfos(const DBImgInfoList &infos, bool showWaitDia
         m_query->addBindValue(pathHashs[i]); //复用上面生成的hash
         m_query->addBindValue(infos[i].filePath);
         m_query->addBindValue(infos[i].getFileNameFromFilePath());
-        m_query->addBindValue(infos[i].time.toString("yyyy.MM.dd"));
-        m_query->addBindValue(infos[i].changeTime.toString(DATETIME_FORMAT_DATABASE));
-        m_query->addBindValue(infos[i].importTime.toString(DATETIME_FORMAT_DATABASE));
+        m_query->addBindValue(infos[i].time);
+        m_query->addBindValue(infos[i].changeTime);
+        m_query->addBindValue(infos[i].importTime);
         m_query->addBindValue(infos[i].itemType);
         if (!m_query->exec()) {
         }
@@ -1618,8 +1777,8 @@ QStringList DBManager::recoveryImgFromTrash(const QStringList &paths)
 
                 }
 
-                info.time = utils::base::stringToDateTime(m_query->value(1).toString());
-                info.changeTime = QDateTime::fromString(m_query->value(2).toString(), DATETIME_FORMAT_DATABASE);
+                info.time = m_query->value(1).toDateTime();
+                info.changeTime = m_query->value(2).toDateTime();
                 info.importTime = QDateTime::currentDateTime();
                 info.itemType = ItemType(m_query->value(4).toInt());
 
@@ -1664,9 +1823,9 @@ QStringList DBManager::recoveryImgFromTrash(const QStringList &paths)
             m_query->addBindValue(info.pathHash);
             m_query->addBindValue(info.filePath);
             m_query->addBindValue(info.getFileNameFromFilePath());
-            m_query->addBindValue(info.time.toString("yyyy.MM.dd"));
-            m_query->addBindValue(info.changeTime.toString(DATETIME_FORMAT_DATABASE));
-            m_query->addBindValue(info.importTime.toString(DATETIME_FORMAT_DATABASE));
+            m_query->addBindValue(info.time);
+            m_query->addBindValue(info.changeTime);
+            m_query->addBindValue(info.importTime);
             m_query->addBindValue(info.itemType);
             if (!m_query->exec()) {
             }
@@ -1767,9 +1926,9 @@ const DBImgInfoList DBManager::getTrashImgInfos(const QString &key, const QStrin
             info.filePath = m_query->value(0).toString();
             if (info.filePath.isEmpty()) //如果路径为空
                 continue;
-            info.time = utils::base::stringToDateTime(m_query->value(3).toString());
-            info.changeTime = QDateTime::fromString(m_query->value(4).toString(), DATETIME_FORMAT_DATABASE);
-            info.importTime = QDateTime::fromString(m_query->value(5).toString(), DATETIME_FORMAT_DATABASE);
+            info.time = m_query->value(3).toDateTime();
+            info.changeTime = m_query->value(4).toDateTime();
+            info.importTime = m_query->value(5).toDateTime();
             info.itemType = ItemType(m_query->value(6).toInt());
 
             infos << info;
