@@ -41,6 +41,10 @@
 #include "batchoperatewidget.h"
 #include "noresultwidget.h"
 
+const int MAINWINDOW_NEEDCUT_WIDTH = 775;
+const int LISTVIEW_MINMUN_WIDTH = 520;
+const int IMPORTTITLE_FIX_WIDTH = 90;
+
 ImportTimeLineView::ImportTimeLineView(DWidget *parent)
     : DWidget(parent), m_mainLayout(nullptr)
     , m_DSlider(nullptr)
@@ -110,6 +114,9 @@ void ImportTimeLineView::initConnections()
     connect(m_importTimeLineListView, &ThumbnailListView::sigSelectAll, this, [ = ]() {
         m_suspensionChoseBtn->setText(QObject::tr("Unselect"));
     });
+
+    // 字体改变时,不同尺寸下同步调整标题栏区域控件显示大小
+    connect(qApp, &QGuiApplication::fontChanged, this, &ImportTimeLineView::updateSize);
 }
 
 void ImportTimeLineView::themeChangeSlot(DGuiApplicationHelper::ColorType themeType)
@@ -341,6 +348,7 @@ void ImportTimeLineView::initTimeLineViewWidget()
     DFontSizeManager::instance()->bind(m_pImportTitle, DFontSizeManager::T3, QFont::DemiBold);
     m_pImportTitle->setForegroundRole(DPalette::TextTitle);
     m_pImportTitle->setFixedHeight(title_HEIGHT);
+    m_pImportTitle->setFixedWidth(IMPORTTITLE_FIX_WIDTH);
     DPalette ppal_light2 = DApplicationHelper::instance()->palette(m_pImportTitle);
     ppal_light2.setBrush(DPalette::Background, ppal_light2.color(DPalette::Base));
     QGraphicsOpacityEffect *opacityEffect_light2 = new QGraphicsOpacityEffect;
@@ -557,6 +565,12 @@ void ImportTimeLineView::resizeEvent(QResizeEvent *ev)
     updateSize();
 }
 
+void ImportTimeLineView::showEvent(QShowEvent *ev)
+{
+    Q_UNUSED(ev);
+    updateSize();
+}
+
 void ImportTimeLineView::dragEnterEvent(QDragEnterEvent *e)
 {
     if (!utils::base::checkMimeUrls(e->mimeData()->urls())) {
@@ -602,6 +616,9 @@ void ImportTimeLineView::clearAllSelection()
 
 void ImportTimeLineView::updateDateNumLabel()
 {
+    if (topLevelWidget()->width() <= MAINWINDOW_NEEDCUT_WIDTH)
+        m_pImportTitle->move(topLevelWidget()->width() - LISTVIEW_MINMUN_WIDTH, 0);
+
     auto fullStr = dateFullStr + "  " + numFullStr;
     auto resultStr = utils::base::reorganizationStr(m_DateNumLabel->font(), fullStr, m_pImportTitle->x() - 19);
     m_DateNumLabel->setText(resultStr);
@@ -617,7 +634,7 @@ void ImportTimeLineView::updateDateNumLabel()
     int size = m_batchOperateWidget->x() - (m_pImportTitle->x() + m_pImportTitle->width());
     QString Str = utils::base::reorganizationStr(m_pImportTitle->font(), tr("Import"), m_pImportTitle->width() + size);
     if (Str.length() > 0) {
-        m_pImportTitle->show();
+        m_pImportTitle->setVisible(size >= 0);
         m_pImportTitle->raise();
     } else {
         m_pImportTitle->hide();
