@@ -67,6 +67,18 @@ const int VIEW_SEARCH = 3;
 const int VIEW_IMAGE = 4;
 const int VIEW_SLIDE = 5;
 
+// 窗口最小尺寸限定
+const int MAINWIDGET_MINIMUN_WIDTH = 630;
+const int MAINWIDGET_MINIMUN_HEIGHT = 300;
+const int SEARCHEDIT_MINIMUN_WIDTH = 110;
+const int SEARCHEDIT_NORMAL_WIDTH = 350;
+const int SEARCHEDIT_SPACE = 20;
+const int BTN_HEIGHT = 36;
+const int TIMEBTN_MIN_WIDTH = 78;
+const int TIMEBTN_NORMAL_WIDTH = 110;
+const int ALBUMBTN_MIN_WIDTH = 55;
+const int ALBUMBTN_NORMAL_WIDTH = 90;
+
 }//namespace
 
 using namespace utils::common;
@@ -103,13 +115,7 @@ MainWindow::~MainWindow()
 void MainWindow::resizeEvent(QResizeEvent *e)
 {
     Q_UNUSED(e);
-    int m_SearchEditWidth = titlebar()->width() - m_titleBtnWidget->width() - TITLEBAR_BLANK_WIDTH;
-    if (m_SearchEditWidth <= 350) {
-        m_pSearchEdit->setFixedSize(m_SearchEditWidth - 20, 36);
-    } else {
-        m_SearchEditWidth = 350;
-        m_pSearchEdit->setFixedSize(m_SearchEditWidth, 36);
-    }
+    adjustTitleContent();
 }
 
 bool MainWindow::eventFilter(QObject *obj, QEvent *event)
@@ -263,9 +269,12 @@ void MainWindow::initShortcut()
 void MainWindow::initUI()
 {
     initWaitDialog();
-    setMinimumSize(880, 500);
+    setMinimumSize(MAINWIDGET_MINIMUN_WIDTH, MAINWIDGET_MINIMUN_HEIGHT);
     resize(1300, 848);
     loadWindowState();
+
+    // 字体改变时,不同尺寸下同步调整标题栏区域控件显示大小
+    connect(qApp, &QGuiApplication::fontChanged, this, &MainWindow::adjustTitleContent);
 }
 
 //初始化等待窗口
@@ -363,7 +372,7 @@ void MainWindow::initTitleBar()
     // TitleBar Search
     m_pSearchEdit = new DSearchEdit(m_titleBtnWidget);
     m_pSearchEdit->lineEdit()->setFocusPolicy(Qt::ClickFocus);
-    m_pSearchEdit->setMaximumSize(350, 36);
+    m_pSearchEdit->setMaximumSize(SEARCHEDIT_NORMAL_WIDTH, 36);
     if (0 < DBManager::instance()->getImgsCount()) {
         m_pSearchEdit->setEnabled(true);
     } else {
@@ -404,6 +413,7 @@ void MainWindow::initTitleBar()
     titlebar()->addWidget(m_titleBtnWidget, Qt::AlignLeft);
 #ifndef tablet_PC
     titlebar()->addWidget(m_pSearchEdit, Qt::AlignHCenter);
+    pTitleBtnLayout->addSpacing(-6);
 #endif
 
     m_addImageBtn = new DIconButton(DStyle::SP_IncreaseElement, this);
@@ -1675,6 +1685,30 @@ void MainWindow::waitImportantProcessBeforeExit()
     }
 }
 
+void MainWindow::adjustTitleContent()
+{
+    int m_SearchEditWidth = titlebar()->width() - m_titleBtnWidget->width() - TITLEBAR_BLANK_WIDTH;
+    if (m_SearchEditWidth <= SEARCHEDIT_NORMAL_WIDTH) {
+        if (m_SearchEditWidth < SEARCHEDIT_MINIMUN_WIDTH) {
+            m_SearchEditWidth = SEARCHEDIT_MINIMUN_WIDTH;
+            m_pTimeBtn->setMaximumSize(TIMEBTN_MIN_WIDTH, BTN_HEIGHT);
+            m_pAlbumBtn->setMaximumSize(ALBUMBTN_MIN_WIDTH, BTN_HEIGHT);
+#ifndef tablet_PC
+            titlebar()->addWidget(m_pSearchEdit, Qt::AlignLeft);
+#endif
+        }
+        m_pSearchEdit->setFixedSize(m_SearchEditWidth - SEARCHEDIT_SPACE, BTN_HEIGHT);
+    } else {
+        m_pTimeBtn->setMaximumSize(TIMEBTN_NORMAL_WIDTH, BTN_HEIGHT);
+        m_pAlbumBtn->setMaximumSize(ALBUMBTN_NORMAL_WIDTH, BTN_HEIGHT);
+#ifndef tablet_PC
+        titlebar()->addWidget(m_pSearchEdit, Qt::AlignHCenter);
+#endif
+        m_SearchEditWidth = SEARCHEDIT_NORMAL_WIDTH;
+        m_pSearchEdit->setFixedSize(m_SearchEditWidth, BTN_HEIGHT);
+    }
+}
+
 void MainWindow::closeEvent(QCloseEvent *event)
 {
     saveWindowState();
@@ -1694,13 +1728,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
 void MainWindow::showEvent(QShowEvent *event)
 {
     Q_UNUSED(event)
-    int m_SearchEditWidth = titlebar()->width() - m_titleBtnWidget->width() - TITLEBAR_BLANK_WIDTH;
-    if (m_SearchEditWidth <= 350) {
-        m_pSearchEdit->setFixedSize(m_SearchEditWidth - 20, 36);
-    } else {
-        m_SearchEditWidth = 350;
-        m_pSearchEdit->setFixedSize(m_SearchEditWidth, 36);
-    }
+    adjustTitleContent();
     QMetaObject::invokeMethod(this, [ = ]() {
         if (m_isFirstStart) {
             if (nullptr == m_pSearchView) {
