@@ -51,6 +51,7 @@
 namespace {
 const int ITEM_SPACING = 4;
 const int BASE_HEIGHT = 100;
+const int MINIMUN_WIDTH = 442;
 
 // const QString IMAGE_DEFAULTTYPE = "All pics";
 const QString IMAGE_DEFAULTTYPE = "All Photos";
@@ -86,7 +87,7 @@ ThumbnailListView::ThumbnailListView(ThumbnailDelegate::DelegateType type, int U
     setContextMenuPolicy(Qt::CustomContextMenu);
     setEditTriggers(QAbstractItemView::NoEditTriggers);
     setSelectionMode(QAbstractItemView::ExtendedSelection);
-    setMinimumWidth(500);
+    setMinimumWidth(MINIMUN_WIDTH);
     m_delegate = new ThumbnailDelegate(type, this); //绑在this上面，用于自动销毁
     m_delegate->m_imageTypeStr = m_imageType;
     setItemDelegate(m_delegate);
@@ -754,6 +755,9 @@ void ThumbnailListView::updateMenuContents()
         if (m_batchOperateWidget && !m_batchOperateWidget->isAllSelectedCollected()) {
             m_MenuActionMap.value(tr("Unfavorite"))->setVisible(false);
             m_MenuActionMap.value(tr("Favorite"))->setVisible(true);
+        } else if (!m_batchOperateWidget && !DBManager::instance()->isAllImgExistInAlbum(DBManager::SpUID::u_Favorite, paths, AlbumDBType::Favourite)) {
+            m_MenuActionMap.value(tr("Unfavorite"))->setVisible(false);
+            m_MenuActionMap.value(tr("Favorite"))->setVisible(true);
         } else {
             m_MenuActionMap.value(tr("Favorite"))->setVisible(false);
             m_MenuActionMap.value(tr("Unfavorite"))->setVisible(true);
@@ -1045,7 +1049,14 @@ void ThumbnailListView::menuItemDeal(QStringList paths, QAction *action)
     }
     break;
     case IdAddToFavorites:
-        m_batchOperateWidget->sltCollectSelect(true); //参数未使用，true false随便传
+        if (m_batchOperateWidget)
+            m_batchOperateWidget->sltCollectSelect(true); //参数未使用，true false随便传
+        else {
+            QStringList paths = selectedPaths();
+            DBManager::instance()->insertIntoAlbum(DBManager::SpUID::u_Favorite, paths, AlbumDBType::Favourite);
+            emit dApp->signalM->insertedIntoAlbum(DBManager::SpUID::u_Favorite, paths);
+            setFocus();
+        }
         break;
     case IdRemoveFromFavorites:
         DBManager::instance()->removeFromAlbum(DBManager::SpUID::u_Favorite, paths, AlbumDBType::Favourite);
