@@ -25,6 +25,8 @@
 #include <QTimer>
 #include <QColor>
 #include <QMimeData>
+#include <dgiovolumemanager.h>
+#include <QtConcurrent/QtConcurrent>
 
 #if QT_VERSION >= 0x050500
 #define TIMER_SINGLESHOT(Time, Code, captured, ...) \
@@ -221,19 +223,14 @@ const QColor LIGHT_IMG_R_BORDER_COLOR = QColor(255, 255, 255, 50);
 }
 
 namespace base {
-//时间之间相差天数
-int         daysDifferenceBetweenTime(const QDateTime &start, const QDateTime &end);
-//void        copyOneImageToClipboard(const QString &path);
 void        copyImageToClipboard(const QStringList &paths);
 void        showInFileManager(const QString &path);
-int         stringHeight(const QFont &f, const QString &str);
 QString     hashByString(const QString &str);
 QString     hashByData(const QString &str);
 QString     SpliteText(const QString &text, const QFont &font, int nLabelSize);
-QDateTime   stringToDateTime(const QString &time);
+std::pair<QDateTime, bool> analyzeDateTime(const QVariant &data);
 QString     getFileContent(const QString &file);
 QPixmap     renderSVG(const QString &filePath, const QSize &size);
-//bool        checkMimeData(const QMimeData *mimeData);
 bool        checkMimeUrls(const QList<QUrl> &urls);
 QString     mkMutiDir(const QString &path);
 //根据源文件路径生产缩略图路径
@@ -259,9 +256,6 @@ const QStringList m_videoFiletypes = {"avs2"/*支持avs2视频格式*/, "3g2", "
                                       , "tp", "trp", "ts", "tts", "txd", "vcd", "vdr", "vob"
                                       , "vp8", "vro", "webm", "wm", "wmv", "wtv", "xesc", "xspf"
                                      };
-QString     Time2str(const qint64 &seconds);
-QString     videoIndex2str(const int &index);
-QString     audioIndex2str(const int &index);
 //判断是否视频
 bool        isVideo(QString path);
 //字符串自适应长度，多的变省略号
@@ -274,6 +268,10 @@ bool trashFile(const QString &file);
 QString getDeleteFullPath(const QString &hash, const QString &fileName);
 //同步文件拷贝，用于区分QFile::copy的异步拷贝
 bool syncCopy(const QString &srcFileName, const QString &dstFileName);
+//可重入版本的getMounts
+QList<QExplicitlySharedDataPointer<DGioMount>> getMounts_safe();
+//快速加载图片
+QFuture<void> multiLoadImage(const QStringList &paths);
 }  // namespace base
 
 }  // namespace utils
