@@ -287,11 +287,18 @@ void ImgInfoDialog::updateBaseInfo(const QMap<QString, QString> &infos)
                 }
                 value = QString::number(tImg.width()) + "x" + QString::number(tImg.height());
             }
+            //重新确认图片方向
+            int orientation = UnionImage_NameSpace::getOrientation(m_path);
+            if (orientation >= 5) { //当方向值大于等于5时，表示触发了90度的旋转，此时需要对调长宽的值
+                auto data = value.split('x');
+                value = data[1] + 'x' + data[0];
+            }
         } else if (i->key.contains("FileFormat")) {
             QStringList list = value.split("/");
             if (list.count() > 0) {
                 value = list.value(list.count() - 1);
             }
+            value = value.toLower(); //统一为小写
         } else if (i->key == "DateTimeOriginal" || i->key == "DateTimeDigitized") {
             QStringList list = value.split(" ");
             if (2 == list.count()) {
