@@ -31,15 +31,13 @@
 #include "allpicview.h"
 #include "imgdeletedialog.h"
 #include "wallpapersetter.h"
-#include "ttbcontent.h"
-#include "viewpanel.h"
-#include "mainwidget.h"
 #include "signalmanager.h"
 #include "../test_qtestDefine.h"
 #include "ac-desktop-define.h"
 #include "testtoolkits.h"
 #include "batchoperatewidget.h"
 #include "imagedataservice.h"
+#include "imageengineapi.h"
 
 TEST(allpicview, test_ini)
 {
@@ -191,9 +189,6 @@ TEST(allpicview, BatchOperateWidget)
 {
     TEST_CASE_NAME("BatchOperateWidget")
 
-    if (ImageEngineApi::instance()->getAllImageDataCount() <= 0) {
-        return;
-    }
     //定位到所有图片
     clickToAllPictureView();
     //定位到第一张图片位置
@@ -249,44 +244,6 @@ TEST(allpicview, BatchOperateWidget)
     }
 }
 
-TEST(allpicview, test_showInFileManagerAndBackGrond)
-{
-//    TEST_CASE_NAME("test_showInFileManagerAndBackGrond")
-//    using namespace utils::base;
-//    using namespace utils::image;
-//    MainWindow *w = dApp->getMainWindow();
-//    AllPicView *a = w->m_pAllPicView;
-//    QString testPath = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation) + QDir::separator() + "test";
-//    ImageEngineApi::instance()->ImportImagesFromFileList((QStringList() << testPath), "", a, false);
-////    QTime t;
-//    QTest::qWait(500);
-//    QStringList paths = ImageEngineApi::instance()->get_AllImagePath();
-//    if (!paths.isEmpty()) {
-//        QString testImage = paths.first();
-////        showInFileManager(testImage);//roc
-////        imageSupportSave(testImage);
-////        checkFileType(testImage);
-//        copyImageToClipboard(paths);
-////        copyOneImageToClipboard(testImage);
-//        WallpaperSetter::instance()->setBackground(testImage);
-//        QTest::qWait(500);
-//        QMimeData *newMimeData = new QMimeData();
-//        QByteArray gnomeFormat = QByteArray("copy\n");
-//        QString text;
-//        QList<QUrl> dataUrls;
-
-//        for (QString path : paths) {
-//            if (!path.isEmpty())
-//                text += path + '\n';
-//            dataUrls << QUrl::fromLocalFile(path);
-//            gnomeFormat.append(QUrl::fromLocalFile(path).toEncoded()).append("\n");
-//        }
-//        newMimeData->setUrls(dataUrls);
-//        checkMimeData(newMimeData);
-//        QTest::qWait(500);
-//    }
-}
-
 TEST(allpicview, viewpaneltest)
 {
     TEST_CASE_NAME("viewpaneltest")
@@ -300,131 +257,16 @@ TEST(allpicview, viewpaneltest)
     tl.addMouseMove(a->m_pImportView->geometry().center());
     tl.simulate(a->m_pImportView);
     QTest::qWait(500);
-//    ImageEngineApi::instance()->ImportImagesFromFileList((QStringList() << testPath), "", a, false);
-//    QTest::qWait(500);
-
-    QStringList testPathlist = ImageEngineApi::instance()->get_AllImagePath();
-    if (!testPathlist.isEmpty()) {
-        qDebug() << "test ImageView Success ";
-        w->m_pSearchEdit->setText("1");
-        w->m_pSearchEdit->editingFinished();
-        QTest::qWait(300);
-
-        emit a->getThumbnailListView()->openImage(0, testPathlist.first(), false);
-        QTest::qWait(300);
-
-        QTestEventList e;
-        e.addKeyClick(Qt::Key_Minus, Qt::ControlModifier, 100);
-        e.addKeyClick(Qt::Key_Minus, Qt::ControlModifier, 100);
-        e.addKeyClick(Qt::Key_Plus, Qt::ControlModifier, 100);
-        e.addKeyClick(Qt::Key_Plus, Qt::ControlModifier, 100);
-        e.addKeyClick(Qt::Key_Plus, Qt::ControlModifier, 100);
-        e.addKeyClick(Qt::Key_Plus, Qt::ControlModifier, 100);
-        e.addKeyClick(Qt::Key_Plus, Qt::ControlModifier, 100);
-        e.simulate(w);
-        e.clear();
-
-//        emit dApp->signalM->showImageInfo(testPathlist.first());
-
-        QTest::qWait(500);
-//        ImgInfoDialog *dialog = w->findChild<ImgInfoDialog *>("ImgInfoDialog");
-//        dialog->height();
-//        dialog->setImagePath(testPath_test + "2k9o1m.png");
-//        dialog->updateInfo();
-//        QPoint p = dialog->pos();
-//        e.addMouseMove(p, 10);
-//        e.addKeyClick(Qt::Key_Escape, Qt::NoModifier, 10);
-//        e.simulate(dialog);
-//        e.clear();
-//        dialog->deleteLater();
-//        QTest::qWait(500);
-//        ViewPanel *viewPanel = w->findChild<ViewPanel *>("ViewPanel");
-
-        QList<QWidget *> widgets = w->findChildren<QWidget *>();
-        foreach (auto widget, widgets) {
-            if (!strcmp(widget->metaObject()->className(), "ViewPanel")) {
-                ViewPanel *viewPanel = dynamic_cast<ViewPanel *>(widget);
-
-                viewPanel->onDeleteByMenu();
-                QTest::qWait(100);
-                viewPanel->onShowExtensionPanel();
-                QTest::qWait(100);
-                viewPanel->onHideExtensionPanel();
-                QTest::qWait(100);
-                viewPanel->onResetTransform(false);
-                QTest::qWait(100);
-                viewPanel->onResetTransform(true);
-                QTest::qWait(100);
-                viewPanel->showNormal();
-                QTest::qWait(100);
-                viewPanel->onHideImageView();
-                QTest::qWait(500);
-                emit a->getThumbnailListView()->openImage(0, testPathlist.first(), false);
-                QTest::qWait(500);
-//                viewPanel->onESCKeyActivated();
-//                QTest::qWait(500);
-                break;
-            }
-        }
-
-        MainWidget *mw = CommandLine::instance()->findChild<MainWidget *>("MainWidget");
-        if (mw) {
-            TTBContent *t = mw->findChild<TTBContent *>("TTBContent");
-            if (t == nullptr) {
-                return;
-            }
-            t->onNextButton();
-            QTest::qWait(500);
-            t->onPreButton();
-            QTest::qWait(500);
-            t->updateFilenameLayout();
-            QTest::qWait(500);
-
-            //todo
-//            MyImageListWidget *imgListView = t->findChild<MyImageListWidget *>("MyImageListWidget");
-//            if (imgListView) {
-//            }
-        }
-    }
-
-    QTestEventList e;
-    e.addKeyClick(Qt::Key_Escape);
-    e.simulate(w);
-}
-
-TEST(allpicview, deleteTips)
-{
-    TEST_CASE_NAME("deleteTips")
-    MainWindow *w = dApp->getMainWindow();
-    w->allPicBtnClicked();
-    QTest::qWait(500);
-    AllPicView *a = w->m_pAllPicView;
-    QStringList testPathlist = ImageEngineApi::instance()->get_AllImagePath();
-    if (testPathlist.count() > 0) {
-        QStringList tempDel;
-        tempDel << testPathlist.last();
-//        ImgDeleteDialog *delDlg = new ImgDeleteDialog(a->getThumbnailListView(), tempDel.length());
-//        delDlg->show();
-//        QTest::qWait(500);
-        ImageEngineApi::instance()->moveImagesToTrash(tempDel);
-//        delDlg->deleteLater();
-        QTest::qWait(500);
-    }
 }
 
 TEST(allpicview, allpicview_other_test)
 {
     TEST_CASE_NAME("allpicview_other_test")
     MainWindow *w = dApp->getMainWindow();
-
-//    w->m_pAllPicView->onMenuOpenImage("", QStringList(), false, false);
-//    w->m_pAllPicView->onImportViewImportBtnClicked();
-
-
     QMimeData mimedata;
     QList<QUrl> li;
     QString lastImportPath =  QStandardPaths::standardLocations(QStandardPaths::PicturesLocation).first();
-    lastImportPath += "/test/4l6r5y.png";
+    lastImportPath += "/AlbumtestResource/test/4l6r5y.png";
     li.append(QUrl(lastImportPath));
     mimedata.setUrls(li);
 
