@@ -66,6 +66,9 @@ TEST(MainWindow, noPicTab)
         ASSERT_FALSE(batch->isVisible());
     }
 
+    //初始状态校验起始UID
+    ASSERT_EQ(DBManager::instance()->albumMaxUID >= DBManager::u_CustomStart, true);
+
     QTestEventList e;
     e.addMouseClick(Qt::MouseButton::LeftButton);
     e.simulate(w->getButG()->button(1));
@@ -203,6 +206,11 @@ TEST(MainWindow, Picimport)
     DBImgInfoList dbInfos;
     dbInfos.push_back(DBImgInfo());
     dApp->m_imageloader->ImportImageLoader(dbInfos);
+
+    //测试快速多图制作
+    QStringList fastTestList{"~/Pictures/AlbumtestResource/2ejqyx.jpg, ~/Pictures/AlbumtestResource/album_ut_mount_point/DCIM/0jll1w.jpg"};
+    auto watcher = utils::base::multiLoadImage(fastTestList);
+    watcher.waitForFinished();
 }
 
 TEST(MainWindow, allpicture)
@@ -321,6 +329,8 @@ TEST(MainWindow, allpicture)
     //------右键菜单start---------
     QTestEventList e;
     auto menu = runContextMenu(allpicview->m_pThumbnailListView->viewport(), p1);
+    auto picIndex = allpicview->m_pThumbnailListView->indexAt(p1);
+    auto path = picIndex.data(Qt::DisplayRole).value<DBImgInfo>().filePath;
     using TR_SUBORDINATE_t = PointerTypeGetter < decltype(allpicview->m_pThumbnailListView) >::type;
 
     //全屏
@@ -384,6 +394,7 @@ TEST(MainWindow, allpicture)
 
     //收藏9
     runActionFromMenu(menu, TR_SUBORDINATE_t::tr("Favorite"));
+    ASSERT_EQ(checkIfInAlbum(path, DBManager::u_Favorite), true);
 
     //顺时针10
     runActionFromMenu(menu, TR_SUBORDINATE_t::tr("Rotate clockwise"));
@@ -531,6 +542,8 @@ TEST(MainWindow, timelineview)
         QTest::qWait(300);
 
         auto menu = runContextMenu(timelineview->getThumbnailListView()->viewport(), pr);
+        auto index = timelineview->getThumbnailListView()->indexAt(pr);
+        auto path = index.data(Qt::DisplayRole).value<DBImgInfo>().filePath;
         using TR_SUBORDINATE_t = PointerTypeGetter < decltype(timelineview->getThumbnailListView()) >::type;
 
         //全屏
@@ -557,6 +570,7 @@ TEST(MainWindow, timelineview)
         e.simulate(timelineview->getThumbnailListView()->viewport());
         e.clear();
         runActionFromMenu(menu, TR_SUBORDINATE_t::tr("Favorite"));
+        ASSERT_EQ(checkIfInAlbum(path, DBManager::u_Favorite), true);
         //顺时针10
         e.addMouseClick(Qt::MouseButton::LeftButton, Qt::NoModifier, pr, 50);
         e.simulate(timelineview->getThumbnailListView()->viewport());
@@ -690,6 +704,8 @@ TEST(MainWindow, AlbumView)
 
     //------右键菜单start---------
     auto menu = runContextMenu(firstThumb->viewport(), p1);
+    auto index = firstThumb->indexAt(p1);
+    auto path = index.data(Qt::DisplayRole).value<DBImgInfo>().filePath;
     using TR_SUBORDINATE_t = PointerTypeGetter < decltype(firstThumb) >::type;
 
     //全屏
@@ -710,6 +726,7 @@ TEST(MainWindow, AlbumView)
 
     //收藏9
     runActionFromMenu(menu, TR_SUBORDINATE_t::tr("Favorite"));
+    ASSERT_EQ(checkIfInAlbum(path, DBManager::u_Favorite), false);
 
     //顺时针10
     runActionFromMenu(menu, TR_SUBORDINATE_t::tr("Rotate clockwise"));
@@ -881,6 +898,8 @@ TEST(MainWindow, favorite)
     QTest::qWait(200);
 
     auto menu3 = runContextMenu(t1->viewport(), p1);
+    auto index = t1->indexAt(p1);
+    auto path = index.data(Qt::DisplayRole).value<DBImgInfo>().filePath;
 
     //设为壁纸12
     runActionFromMenu(menu3, TR_SUBORDINATE_t::tr("Set as wallpaper"));
@@ -898,6 +917,7 @@ TEST(MainWindow, favorite)
 
     //收藏9
     runActionFromMenu(menu3, TR_SUBORDINATE_t::tr("Favorite"));
+    ASSERT_EQ(checkIfInAlbum(path, DBManager::u_Favorite), false);
 
     ASSERT_TRUE(w->m_pAlbumview != nullptr);
 }
@@ -1423,20 +1443,6 @@ TEST(MainWindow, wheelEvent)
     w->wheelEvent(&event_3);
 }
 
-//从菜单关闭
-TEST(MainWindow, closeFromMenu)
-{
-    TEST_CASE_NAME("closeFromMenu")
-
-    MainWindow *w = dApp->getMainWindow();
-    stub_ext::StubExt stu;
-
-    //这里需要干掉instance，否则测试结束进行清理的时候会崩
-    stu.set_lamda(&MainWindow::instance, [w]() -> MainWindow& {
-        return *w;
-    });
-}
-
 //搜索框
 TEST(MainWindow, onSearchEditIsDisplay)
 {
@@ -1557,7 +1563,23 @@ TEST(MainWindow, monitor)
 {
     TEST_CASE_NAME("monitor")
 
-    //删除一次文件
-    std::system(("rm -rf " + testPath_Pictures + "/Draw/2ejqyx.jpg").toStdString().c_str());
     QTest::qWait(2000);
+
+    auto infosInVideos = utils::image::getImagesAndVideoInfo(QStandardPaths::writableLocation(QStandardPaths::MoviesLocation) + "/Screen Recordings");
+    auto infosInPictures = utils::image::getImagesAndVideoInfo(QStandardPaths::writableLocation(QStandardPaths::PicturesLocation) + "/Screenshots");
+
+    auto infosCount = infosInVideos.size() + infosInPictures.size();
+
+    ASSERT_EQ(DBManager::instance()->getAlbumImgsCount(DBManager::u_ScreenCapture), infosCount);
+
+    for (auto &currentInfo : infosInVideos) {
+        QFile currentFile(currentInfo.absoluteFilePath());
+        currentFile.copy(currentInfo.absoluteFilePath() + "." + currentInfo.suffix());
+    }
+
+    QFile::remove(infosInPictures[0].absoluteFilePath());
+
+    QTest::qWait(5000);
+
+    ASSERT_EQ(DBManager::instance()->getAlbumImgsCount(DBManager::u_ScreenCapture), infosCount + infosInVideos.size() - 1);
 }
