@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Elimina</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Tutto schermo</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Presentazione</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Esporta</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Copia</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Agg. ai preferiti</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Ruota in senso orario</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Ruota in senso antiorario</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Imposta come sfondo</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Visualizza nel File Manager</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Info immagine</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Video info</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Ripristina</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>Oppure trascina le immagini qui</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 immagine(i)</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Importa tutti</translation>
@@ -108,11 +159,11 @@
     </message>
     <message>
         <source>Loading...</source>
-        <translation type="unfinished"/>
+        <translation>Caricamento...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
-        <translation type="unfinished"/>
+        <source>The files will be permanently deleted after the days shown on them</source>
+        <translation>I file verranno eliminati definitivamente dopo i giorni indicati</translation>
     </message>
 </context>
 <context>
@@ -201,6 +252,25 @@
         <translation>esiste già, desideri sostituirla?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>Annulla</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Info immagine</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Sei sicuro di eliminare questa foto dall&apos;album?</translation>
+        <translation type="vanished">Sei sicuro di eliminare questa foto dall&apos;album?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation type="vanished"><numerusform>Sicuro di voler eliminare %n immagini dall&apos;album?</numerusform><numerusform>Sicuro di voler eliminare %n immagini dall&apos;album?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation type="unfinished"/>
+        <translation type="vanished">Sei sicuro di eliminare questo video dall&apos;album?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation type="vanished"><numerusform>Sicuro di voler eliminare %n video dall&apos;album?</numerusform><numerusform>Sicuro di voler eliminare %n video dall&apos;album?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation type="vanished"><numerusform>Sicuro di voler eliminare %n elementi dall&apos;album?</numerusform><numerusform>Sicuro di voler eliminare %n elementi dall&apos;album?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,7 +390,7 @@
         <translation>Dettagli</translation>
     </message>
     <message>
-        <source>Photo info</source>
+        <source>Image info</source>
         <translation>Info immagine</translation>
     </message>
 </context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Tutte le immagini e video</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Nessuna immagine o video trovati</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Nuovo album</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -525,10 +617,6 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
         <source>Settings</source>
         <translation>Impostazioni</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Importa immagini</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Importazione...</translation>
@@ -547,11 +635,11 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
     </message>
     <message>
         <source>Export photos</source>
-        <translation type="unfinished"/>
+        <translation>Esporta foto</translation>
     </message>
     <message>
         <source>Import photos/videos</source>
-        <translation type="unfinished"/>
+        <translation>Importa foto/video</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -559,6 +647,30 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
     </message>
     <message>
         <source>Photo/Video info</source>
+        <translation>Info Foto/Video</translation>
+    </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation>Importa foto e video</translation>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -645,8 +757,8 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
         <translation>Tag</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Nome immagine</translation>
+        <source>Name</source>
+        <translation>Nome</translation>
     </message>
 </context>
 <context>
@@ -814,30 +926,7 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
     </message>
     <message numerus="yes">
         <source>%n photos found</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
-    </message>
-</context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Pausa</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Avvia</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Esci</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Precedente</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Successiva</translation>
+        <translation><numerusform>%n foto trovate</numerusform><numerusform>%n foto trovate</numerusform></translation>
     </message>
 </context>
 <context>
@@ -860,54 +949,11 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
     </message>
     <message>
         <source>Importing: %1</source>
-        <translation type="unfinished"/>
+        <translation>Importazione: %1</translation>
     </message>
     <message>
         <source>Exporting: %1</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Indietro</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Precedente</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Successiva</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>Dimensione 1:1</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Adatta alla finestra</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Ruota in senso antiorario</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Ruota in senso orario</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Elimina</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Agg. ai preferiti</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Sposta dai preferiti</translation>
+        <translation>Esportazione: %1</translation>
     </message>
 </context>
 <context>
@@ -993,17 +1039,6 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
         <translation>giorni</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>Nessun file immagine trovato</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Immagine non trovata</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1085,10 +1120,6 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
         <source>Sampling</source>
         <translation>Campionamento</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>Nome video</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Data modifica</translation>
@@ -1117,84 +1148,9 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
         <source>Date captured</source>
         <translation>Data acquisizione</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Aggiungi all&apos;album</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Presentazione</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Esci da schermo intero</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Tutto schermo</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Copia</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Elimina</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Mostra finestra di navigazione</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Nascondi finestra di navigazione</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Ruota in senso orario</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Ruota in senso antiorario</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Imposta come sfondo</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Visualizza nel File Manager</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Esporta</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Sposta dai preferiti</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Info immagine</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Rimuovi dall&apos;album</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Agg. ai preferiti</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Nuovo album</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Stampa</translation>
+        <source>Name</source>
+        <translation>Nome</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
