@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Удалить</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">На весь экран</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Слайд-шоу</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Экспорт</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Копировать</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Добавить в избранное</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Повернуть по часовой стрелке</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Повернуть против часовой стрелки</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Установить в качестве обоев</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Отображать в файловом менеджере</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Информация о фотографии</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Информация о  видео</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Восстановить</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>Или перетащите фотографии сюда</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 фотография(-ий)</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Импортировать всё</translation>
@@ -111,8 +162,8 @@
         <translation>Загрузка...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
-        <translation>Файлы будут безвозвратно удалены по истечении указанного времени</translation>
+        <source>The files will be permanently deleted after the days shown on them</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -201,6 +252,25 @@
         <translation>уже существует. Вы хотите его заменить?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>Отмена</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Информация о фотографии</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,23 +328,55 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Вы уверены, что хотите удалить эту фотографию из альбома?</translation>
+        <translation type="vanished">Вы уверены, что хотите удалить эту фотографию из альбома?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform></translation>
+        <translation type="vanished"><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this video from the album?</source>
-        <translation>Вы уверены, что хотите удалить это видео из альбома?</translation>
+        <translation type="vanished">Вы уверены, что хотите удалить это видео из альбома?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform></translation>
+        <translation type="vanished"><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform></translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n items from albums?</source>
-        <translation><numerusform>Вы уверены, что хотите удалить %n элемент из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n элементов из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n элементов из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n элементов из альбомов?</numerusform></translation>
+        <translation type="vanished"><numerusform>Вы уверены, что хотите удалить %n элемент из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n элементов из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n элементов из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n элементов из альбомов?</numerusform></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -295,8 +390,8 @@
         <translation>Подробные сведения</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Информация о фотографии</translation>
+        <source>Image info</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Все фото и видео</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Ни фото, ни видео не найдено</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Новый альбом</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>У Вас нет разрешения на просмотр файла</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Параметры</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Импорт фотографий</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Импортирование...</translation>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation>Информация о фото/видео</translation>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,8 +756,8 @@
         <translation>Тег</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Название фотографии</translation>
+        <source>Name</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -816,29 +928,6 @@
         <translation><numerusform>Найдено %n фото</numerusform><numerusform>Найдено %n фото</numerusform><numerusform>Найдено %n фото</numerusform><numerusform>Найдено %n фото</numerusform></translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Пауза</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Воспроизвести</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Выход</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Предыдущий</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Следующий</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
     <message>
@@ -866,49 +955,6 @@
         <translation>Экспортировано: %1</translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Назад</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Предыдущий</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Следующий</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>Размер 1:1</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Подходит для окна</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Повернуть против часовой стрелки</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Повернуть по часовой стрелке</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Удалить</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Избранное</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Удалить из избранного</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>дней</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>Файлы изображений не найдены</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Фотографии не найдены</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation>Сэмплирование</translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation>Название видео</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Дата изменения</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Дата создания</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Добавить в альбом</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Слайд-шоу</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Выход из полноэкранного режима</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>На весь экран</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Копировать</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Удалить</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Показать окно навигации</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Скрыть окно навигации</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Повернуть по часовой стрелке</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Повернуть против часовой стрелки</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Установить в качестве обоев</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Отображать в файловом менеджере</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Экспорт</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Удалить из избранного</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Информация о фотографии</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Удалить из альбома</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Избранное</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Новый альбом</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Печать</translation>
+        <source>Name</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 </TS>
\ No newline at end of file
